Learn R Programming

filteRjsats (version 1.0)

compare_detects: Compare two Detection Dataframes

Description

This function compares two detection dataframes from filtered acoustic telemetry detections and identifies the filtered out detections. The first input is the original dataframe, the second is the filtered dataframe. Then it creates a dataframe of detections which are missing from the filtered dataframe.

Usage

compare_detects(a1, a2)

Value

A dataframe of detections from the original dataframe missing from the filtered dataframe. Spurious detections.

Arguments

a1

unfiltered detection dataframe

a2

filtered detection dataframe

Examples

Run this code
# Compare detections before and after filtering
compare_detects(raw_ats[1:1000,], filter_fish_detects[1:1000,])

Run the code above in your browser using DataLab