An example dataset of real acoustic telemetry detections of fish at several
receivers within the California Central Valley from 2021. These detections
have already been been processed to remove false positives using the various
filtering functions in this package and in companion package filteRjsats.
filtered_detectionsfiltered_detections
A data frame with 100,000 rows and 3 columns:
The serial number of the detecting receiver
the local time of the detection (tz = America/Los_Angeles)
The hexadecimal acoustic tag ID code