Learn R Programming

filteRjsats (version 1.0)

fish_detects: Example fish detection data

Description

Example tag detection data from CalFishTrack representing fish released in 2021.

Usage

fish_detects

Arguments

Format

fish_detects

A dataframe with 10,000 rows and 3 columns

ReceiverSN

the serial number of the acoustic receiver which heard the detection

DateTime_Local

The local date and time of the detection tz = "America/Los_Angeles"

Tag_Code

The hexadecimal value of the acoustic tag ID code