A dataframe of detections which has gone through the prefilter() function
prefiltered_detectsprefiltered_detects
A dataframe with 209,149 rows and 12 columns
the serial number of the acoustic receiver which heard the detection
The Manufacturer of the acoustic reciever
The local date and time of the detection tz = "America/Los_Angeles"
The decimal value of the tag ID code
The hexadecimal value of the tag ID code
The tilt of the acoustic receiver from a vertical axis
The voltage of the on-board battery of the receiver
The water temperature outside of the receiver
The strength of the acoustic signal in dB
The frequency of the acoustic signal in kHz
The relative amount of external background noise, signal threshold
A calculated field from the first filter checking the time between acoustic transmissions from the same tag was >0.3secs