Learn R Programming

filteRjsats (version 1.0)

read_ats: Read an ATS Acoustic Receiver File

Description

This function takes a raw acoustic detection file generated by an ATS JSATS receiver and processes it into a dataframe which can be used by the filtering functions in this package.This is called within read_jsats().

Usage

read_ats(path, file, timezone = "America/Los_Angeles")

Value

A dataframe converting the raw detection data into rows of detections

Arguments

path

the path to the folder containing the desired file

file

the path of the desired file

timezone

the Olsen Named time zone, default is "America/Los_Angeles"

Examples

Run this code
# Read in an ATS file
path = system.file("extdata/", package = "filteRjsats")
read_ats(path = path, file = "17111___210531_115356.csv",
timezone = "America/Los_Angeles")
# Warnings are expected due to the formatting of ATS files

Run the code above in your browser using DataLab