Learn R Programming

filteRjsats (version 1.0)

read_jsats: Read an Acoustic Receiver File

Description

This function takes a raw acoustic detection file generated by a Lotek, Teknologic, or ATS JSATS receiver and determines which reader function to use to process it into a dataframe which can be used by the filtering functions in this package.

Usage

read_jsats(path, file, timezone = "America/Los_Angeles")

Value

A dataframe converting the raw detection data into rows of detections

Arguments

path

the path to the folder containing the desired file

file

the path of the desired file

timezone

the Olsen Named time zone, default is "America/Los_Angeles"

Examples

Run this code
# Read in any ATS, LOTEK, TEKNO file

# list of files
path = system.file("extdata", package = "filteRjsats")
files <- list.files(path)

# Read the files
raw_data <- list()
for(i in 1:length(files)){
raw_data[[i]] <- read_jsats(path = path, file = files[i],
timezone = "America/Los_Angeles")
}
# Warnings are expected due to the formatting of ATS files

Run the code above in your browser using DataLab