Learn R Programming

filteRjsats (version 1.0)

read_lotek: Read a Lotek Acoustic Receiver File

Description

This function takes a raw acoustic detection file generated by a Lotek JSATS receiver and processes it into a dataframe which can be used by the filtering functions in this package.This is called within read_jsats().

Usage

read_lotek(path, file, timezone = "America/Los_Angeles")

Value

A dataframe converting the raw detection data into rows of detections

Arguments

path

the path to the folder containing the desired file

file

the path of the desired file

timezone

the Olsen Named time zone, default is "America/Los_Angeles"

Examples

Run this code
# see read_ats or read_tekno for example usage

Run the code above in your browser using DataLab