Learn R Programming

filteRjsats (version 1.0)

read_tekno: Read a Teknologic Acoustic Receiver File

Description

This function takes a raw acoustic detection file generated by a Teknologic JSATS receiver and processes it into a dataframe which can be used by the filtering functions in this package. This is called within read_jsats().

Usage

read_tekno(path, file, timezone = "America/Los_Angeles")

Value

A dataframe converting the raw detection data into rows of detections

Arguments

path

the path to the folder containing the desired file

file

the path of the desired file

timezone

the Olsen Named time zone, default is "America/Los_Angeles"

Examples

Run this code
# Read in a Teknologic file
path = system.file("extdata/", package = "filteRjsats")
read_tekno(path = path, file = "2015-6007211361217.SUM",
timezone = "America/Los_Angeles")

Run the code above in your browser using DataLab