second_filter_2h4h: Two or Four Hit Filter for Any Detection File
Description
This function takes any acoustic receiver detection dataframe generated from
the add_fish() function and filters it a second time to remove any remaining
multipath detections. Then depending on the type of receiver file applies an
algorithm to assess and filter all remaining detections based on 2 or 4 hits.
Usage
second_filter_2h4h(fish_file)
Value
A dataframe which has been filtered to remove false positives
Arguments
fish_file
a dataframe of detections retrieved from add_fish()