This function compares two detection dataframes from filtered acoustic
telemetry detections and identifies the filtered out detections. The first
input is the original dataframe, the second is the filtered dataframe. Then
it creates a dataframe of detections which are missing from the filtered
dataframe.
Usage
compare_detects(a1, a2)
Value
A dataframe of detections from the original dataframe missing from
the filtered dataframe. Spurious detections.