powered by
This function takes a raw acoustic detection file generated by a Lotek JSATS receiver and processes it into a dataframe which can be used by the filtering functions in this package.This is called within read_jsats().
read_lotek(path, file, timezone = "America/Los_Angeles")
A dataframe converting the raw detection data into rows of detections
the path to the folder containing the desired file
the path of the desired file
the Olsen Named time zone, default is "America/Los_Angeles"
# see read_ats or read_tekno for example usage
Run the code above in your browser using DataLab