read_tekno: Read a Teknologic Acoustic Receiver File
Description
This function takes a raw acoustic detection file generated by a Teknologic
JSATS receiver and processes it into a dataframe which can be used by
the filtering functions in this package. This is called within read_jsats().