second_filter_lotek: Four Hit Filter for Lotek Detections
Description
This function takes a Lotek detection dataframe generated from the add_fish()
function and filters it a second time to remove any remaining multipath
detections, and then check the remaining detections by comparing the time
between detections, for a rolling window of 4 detections to ensure it is less
16.6x the stated pulse rate interval. It additionally checks that all
detections within the window occur within 20% of the pulse rate interval of
the other detections and that the standard deviation of pulse rate intervals
is less than 0.025. Called by second_filter().
Usage
second_filter_lotek(fish_file)
Value
A dataframe which has been filtered to remove false positives
Arguments
fish_file
a dataframe of detections retrieved from add_fish()